import { BaseClient, ClientConfig } from "@commerce-apps/core";
import { ZoneResponse, RecommendersResponse, ActivityResponse, RecommendationsResponse } from "./einsteinApiQuickStartGuide.types";
export { ClientIdParam, CookieIdParam, Error, ProductForView, ProductForCheckout, UserIdParam, SiteIdParam, Recommender, ClientIpParam, ZoneResponse, RecommendersResponse, ActivityResponse, UuidParam, ClientUserAgentParam, RecommendationsResponse, } from "./einsteinApiQuickStartGuide.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Tells the Einstein engine when a user views a product.
    */
    sendViewProduct(options: {
        rawResponse?: boolean;
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine when a user views a set of recommendations
    */
    sendViewReco(options: {
        rawResponse?: boolean;
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine when a user clicks on a recommendation
    */
    sendClickReco(options: {
        rawResponse?: boolean;
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Tells the Einstein engine when a user adds an item to their cart.
    */
    sendAddToCart(options: {
        rawResponse?: boolean;
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ActivityResponse>;
    /**
    * Get a list of recommenders that can be used in recommendation requests.
    */
    getRecommenders(options?: {
        rawResponse?: boolean;
        parameters?: {
            siteId: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | RecommendersResponse>;
    /**
    * Get a set of recommendations
    */
    getRecommendations(options: {
        rawResponse?: boolean;
        parameters?: {
            siteId: any;
            recommenderName: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | RecommendationsResponse>;
    /**
    * Get a set of recommendations for a zone
    */
    getZoneRecommendations(options: {
        rawResponse?: boolean;
        parameters?: {
            siteId: any;
            zoneName: any;
            clientId: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | ZoneResponse>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=einsteinApiQuickStartGuide.d.ts.map