import { BaseClient, ClientConfig } from "@commerce-apps/core";
import { PaymentMethodResult, Order } from "./shopperOrders.types";
export { SiteId, SearchRequest, PaginatedSearchResult, SimpleSearchResult, PaymentCardSpec, OrderAddress, BasketsResult, PaymentCard, NotesResult, ShippingItem, Discount, Note, CouponItem, PromotionLink, ShippingPromotion, ProductItem, BasketPaymentInstrumentRequest, OrderPaymentInstrument, BonusDiscountLineItem, PaymentMethodResult, Shipment, CustomerInfo, SimpleLink, PriceAdjustment, ShippingMethodResult, ProductDetailsLink, OptionItem, ShippingMethod, Basket, OrderPaymentInstrumentRequest, GiftCertificateItem, ProductListLink, Order, OrderPaymentCardRequest, PaymentMethod, Status, ProductListItemReference, ErrorResponse, Offset, Limit, } from "./shopperOrders.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
export declare class Client extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Submits an order based on a prepared basket. The only considered value from the request body is basketId.
    */
    postOrders(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Order>;
    /**
    * Gets information for an order.
    */
    getOrdersById(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Order>;
    /**
    * Adds a payment instrument to an order.

Details:

The payment instrument is added with the provided details. The payment method must be applicable for the order see GET
/baskets/{basketId}/payment-methods, if the payment method is &#x27;CREDIT_CARD&#x27; a paymentCard must be specified in the request.
    */
    postOrdersByIdPaymentInstruments(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Order>;
    /**
    * Removes a payment instrument of an order.
    */
    deleteOrdersByIdPaymentInstrumentsById(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            paymentInstrumentId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | Order>;
    /**
    * Updates a payment instrument of an order.

Details:

The payment instrument is updated with the provided details. The payment method must be applicable for the
order see GET /baskets/{basketId}/payment-methods, if the payment method is &#x27;CREDIT_CARD&#x27; a
paymentCard must be specified in the request.
    */
    patchOrdersByIdPaymentInstrumentsById(options: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            paymentInstrumentId: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<Response | Order>;
    /**
    * Gets the applicable payment methods for an existing order considering the open payment amount only.
    */
    getOrdersByIdPaymentMethods(options?: {
        rawResponse?: boolean;
        parameters?: {
            organizationId?: any;
            orderNo: any;
            siteId?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<Response | PaymentMethodResult>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=shopperOrders.d.ts.map